/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { DoublyLinkedList, walkList } from "./collections/index.js";
export class SegmentGroupCollection {
    constructor(segment) {
        this.segment = segment;
        this.segmentGroups = new DoublyLinkedList();
    }
    get size() {
        return this.segmentGroups.length;
    }
    get empty() {
        return this.segmentGroups.empty;
    }
    enqueue(segmentGroup) {
        this.segmentGroups.push(segmentGroup);
        segmentGroup.segments.push(this.segment);
    }
    dequeue() {
        return this.segmentGroups.shift()?.data;
    }
    remove(segmentGroup) {
        const found = this.segmentGroups.find((v) => v.data === segmentGroup);
        if (found === undefined) {
            return false;
        }
        this.segmentGroups.remove(found);
        return true;
    }
    pop() {
        return this.segmentGroups.pop ? this.segmentGroups.pop()?.data : undefined;
    }
    copyTo(segmentGroups) {
        walkList(this.segmentGroups, (sg) => segmentGroups.enqueueOnCopy(sg.data, this.segment));
    }
    enqueueOnCopy(segmentGroup, sourceSegment) {
        this.enqueue(segmentGroup);
        if (segmentGroup.previousProps) {
            // duplicate the previousProps for this segment
            const index = segmentGroup.segments.indexOf(sourceSegment);
            if (index !== -1) {
                segmentGroup.previousProps.push(segmentGroup.previousProps[index]);
            }
        }
    }
}
//# sourceMappingURL=segmentGroupCollection.js.map